The
get_summary_records() has been
deprecated in favor of derive_summary_records() (call it with the dataset_add
argument and without the dataset argument).
It is not uncommon to have an analysis need whereby one needs to derive an
analysis value (AVAL) from multiple records. The ADaM basic dataset
structure variable DTYPE is available to indicate when a new derived
records has been added to a dataset.
Arguments
- dataset
-
Input dataset
The variables specified by the
by_varsargument are expected to be in the dataset.- Default value
none
- by_vars
-
Grouping variables
Variables to consider for generation of groupwise summary records.
- Default value
none
- filter
-
Filter condition as logical expression to apply during summary calculation. By default, filtering expressions are computed within
by_varsas this will help when an aggregating, lagging, or ranking function is involved.For example,
filter_rows = (AVAL > mean(AVAL, na.rm = TRUE))will filter all AVAL values greater than mean of AVAL with inby_vars.filter_rows = (dplyr::n() > 2)will filter n count ofby_varsgreater than 2.
- Default value
NULL
- set_values_to
-
Variables to be set
The specified variables are set to the specified values for the new observations.
Set a list of variables to some specified value for the new records
LHS refer to a variable.
RHS refers to the values to set to the variable. This can be a string, a symbol, a numeric value, an expression or NA. If summary functions are used, the values are summarized by the variables specified for
by_vars.
For example:
- Default value
NULL
Details
This function only creates derived observations and does not append them
to the original dataset observations. If you would like to this instead,
see the derive_summary_records() function.